==> qtjambi-debuginfo-linux-x64-5.15.17.jar: sources/QtJambiWidgets/QStyleHintReturnVariant_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtWidgets/qstyleoption.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QStyleHintReturnVariant(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QStyleHintReturnVariant")
    QStyleHintReturnVariant *_ptr = reinterpret_cast<QStyleHintReturnVariant *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QStyleHintReturnVariant()
void __qt_construct_QStyleHintReturnVariant_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QStyleHintReturnVariant()")
    Q_UNUSED(__java_arguments)
    QStyleHintReturnVariant *__qt_this = new(__qtjambi_ptr) QStyleHintReturnVariant();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// destruct QStyleHintReturnVariant
void __qt_destruct_QStyleHintReturnVariant(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QStyleHintReturnVariant")
    reinterpret_cast<QStyleHintReturnVariant*>(ptr)->~QStyleHintReturnVariant();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QStyleHintReturnVariant::QStyleHintReturnVariant()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleHintReturnVariant_initialize_1native__Lio_qt_widgets_QStyleHintReturnVariant_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QStyleHintReturnVariant::QStyleHintReturnVariant()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QStyleHintReturnVariant_0, sizeof(QStyleHintReturnVariant), typeid(QStyleHintReturnVariant), false, &deleter_QStyleHintReturnVariant, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting Field accessors (writeFieldAccessors)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleHintReturnVariant_setVariant_1native_1cref_1QVariant__JLjava_lang_Object_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jobject variant0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QStyleHintReturnVariant *__qt_this = QtJambiAPI::objectFromNativeId<QStyleHintReturnVariant>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QVariant  __qt_variant0 = qtjambi_cast<QVariant >(__jni_env, variant0);
        __qt_this->variant = __qt_variant0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleHintReturnVariant_variant_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QStyleHintReturnVariant *__qt_this = QtJambiAPI::objectFromNativeId<QStyleHintReturnVariant>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QVariant&  __qt_value = __qt_this->variant;
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleHintReturnVariant_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QStyleHintReturnVariant *__qt_this = QtJambiAPI::objectFromNativeId<QStyleHintReturnVariant>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QStyleHintReturnVariant(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QStyleHintReturnVariant>("QStyleHintReturnVariant", "io/qt/widgets/QStyleHintReturnVariant");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QStyleHintReturnVariant, {
        ConstructorInfo(&__qt_construct_QStyleHintReturnVariant_0, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QStyleHintReturnVariant);
    registerMetaType<QStyleHintReturnVariant>("QStyleHintReturnVariant");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-debuginfo-linux-x64-6.5.7.jar: sources/QtJambiWidgets/QStyleHintReturnVariant_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtWidgets/qstyleoption.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QStyleHintReturnVariant(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QStyleHintReturnVariant")
    QStyleHintReturnVariant *_ptr = reinterpret_cast<QStyleHintReturnVariant *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QStyleHintReturnVariant()
void __qt_construct_QStyleHintReturnVariant(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QStyleHintReturnVariant()")
    Q_UNUSED(__java_arguments)
    QStyleHintReturnVariant *__qt_this = new(__qtjambi_ptr) QStyleHintReturnVariant();
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
}

// QStyleHintReturnVariant::QStyleHintReturnVariant()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleHintReturnVariant_initialize_1native__Lio_qt_widgets_QStyleHintReturnVariant_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QStyleHintReturnVariant::QStyleHintReturnVariant()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QStyleHintReturnVariant, sizeof(QStyleHintReturnVariant), typeid(QStyleHintReturnVariant), 0, false, &deleter_QStyleHintReturnVariant, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QStyleHintReturnVariant
void __qt_destruct_QStyleHintReturnVariant(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QStyleHintReturnVariant")
    reinterpret_cast<QStyleHintReturnVariant*>(ptr)->~QStyleHintReturnVariant();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// emitting Field accessors (writeFieldAccessors)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleHintReturnVariant_setVariant_1native_1cref_1QVariant__JLjava_lang_Object_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jobject variant0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QStyleHintReturnVariant *__qt_this = QtJambiAPI::objectFromNativeId<QStyleHintReturnVariant>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QVariant  __qt_variant0 = qtjambi_cast<QVariant >(__jni_env, variant0);
        __qt_this->variant = __qt_variant0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QStyleHintReturnVariant_variant_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QStyleHintReturnVariant *__qt_this = QtJambiAPI::objectFromNativeId<QStyleHintReturnVariant>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QVariant&  __qt_value = __qt_this->variant;
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QStyleHintReturnVariant(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QStyleHintReturnVariant>("QStyleHintReturnVariant", "io/qt/widgets/QStyleHintReturnVariant");
// BEGIN: function table
    registerConstructorInfos(typeId, 0, &__qt_destruct_QStyleHintReturnVariant, {
        ConstructorInfo(&__qt_construct_QStyleHintReturnVariant, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QStyleHintReturnVariant);
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
